Calculates vapor pressure from relative humidity and saturation vapor pressure.
Usage
pres_vapor_p(...)
# Default S3 method
pres_vapor_p(temp, rh, ...)
# S3 method for class 'weather_station'
pres_vapor_p(weather_station, ...)Calculates vapor pressure from relative humidity and saturation vapor pressure.
pres_vapor_p(...)
# Default S3 method
pres_vapor_p(temp, rh, ...)
# S3 method for class 'weather_station'
pres_vapor_p(weather_station, ...)