Skip to contents

Calculates soil volumetric heat capacity (MJ / (m³ * K)) from soil moisture and texture. Works by linearly interpolating volumetric heat capacity based on measured data. Moisture is supplied as m3 m-3 and converted internally to volume percent.

Usage

soil_heat_cap(...)

# Default S3 method
soil_heat_cap(moisture, texture = "sand", ...)

# S3 method for class 'weather_station'
soil_heat_cap(weather_station, ...)

Arguments

...

Additional arguments.

moisture

Soil moisture in cubic meters per cubic meter.

texture

Soil texture. Either "sand", "peat" or "clay".

weather_station

A weather_station object.

Value

Soil volumetric heat capacity in MJ/(m³ * K).

Details

The volumetric heat capacity (\(C_v\)) of the soil is determined based on its texture and moisture content. The values are interpolated from measured data for different soil types. Values below the tabulated moisture domain return NA; values above the tabulated domain use the highest tabulated heat capacity. The sand, clay and peat tables are package lookup values cited to Bendix (2004) appendix material.

References

Bendix 2004, p. 254.

Examples

# Calculate soil volumetric heat capacity
soil_heat_cap(moisture = 0.25, texture = "sand")
#> [1] 2.21