Calculates absolute humidity from vapor pressure and air temperature.
Usage
hum_absolute(...)
# Default S3 method
hum_absolute(rh, temp, ...)
# S3 method for class 'weather_station'
hum_absolute(weather_station, ...)Details
Absolute humidity (\(AH\)) is the mass of water vapor per unit volume of air. It is calculated from the vapor pressure and temperature using the formula: $$AH = \frac{0.21668 \times pvapor}{T}$$ where \(pvapor\) is the vapor pressure and \(T\) is the temperature in Kelvin. The formula and constants follow the Bendix (2004) humidity helper background used by the package.