Checks if the climate station is positioned within the maximum allowable distance from the obstacle.
Value
A message indicating if the climate station is well positioned or if it needs to be moved closer to the obstacle.
Details
The maximum distance is calculated to ensure that the climate station's measurements are within a reasonable range from the obstacle. If the station is positioned too far, it needs to be moved closer.
Formula used:
For a circularly surrounded obstacle: \(d_{max} = 15 \cdot h\)
For an obstacle behind the station:
If \(h > w\): \(d_{max} = 15 \cdot w\)
If \(h < w\): \(d_{max} = 15 \cdot h\)
Examples
# Check maximum distance for an obstacle behind the station
pos_max_dist(dist = 500, obs_width = 50, obs_height = 30)
#> [1] "The climate station is positioned too far from the obstacle. It needs to be placed in a position closer than 450 m from the obstacle."
# Check maximum distance for a circularly surrounded obstacle
pos_max_dist(dist = 500, obs_width = 50, obs_height = 30, ring = TRUE)
#> [1] "The climate station is positioned too far from the obstacle. It needs to be placed in a position closer than 450 m from the obstacle."