Calculates the sum of longwave incoming and outgoing radiation.
Usage
rad_lw_bal(...)
# Default S3 method
rad_lw_bal(temp, rh, slope, valley, surface_type, surface_temp, ...)
# S3 method for class 'weather_station'
rad_lw_bal(weather_station, ...)Arguments
- ...
Named station fields, site parameters or model assumptions.
- temp
Air temperature in degrees C.
- rh
Relative humidity in percent.
- slope
Slope in degrees.
- valley
Logical value indicating whether the station is in a valley.
- surface_type
Surface-type label.
- surface_temp
Surface temperature in degrees C.
- weather_station
A weather_station object.