Calculates soil thermal conductivity from soil texture and soil moisture. Works by linearly interpolating thermal conductivity based on measured data. Moisture is supplied as m3 m-3 and converted internally to volume percent.
Usage
soil_thermal_cond(...)
# Default S3 method
soil_thermal_cond(texture, moisture, ...)
# S3 method for class 'weather_station'
soil_thermal_cond(weather_station, ...)Details
The thermal conductivity (\(\lambda\)) of the soil is determined based on its texture and moisture content.
The values are interpolated from measured data for different soil types.
Values outside the tabulated moisture domain return NA.
The sand, clay and peat tables are package lookup values cited to Bendix
(2004) appendix material.