Calculates the sky view factor, which represents how much sky can be seen from a given point.
Usage
terr_sky_view(...)
# Default S3 method
terr_sky_view(slope, valley, ...)
# S3 method for class 'weather_station'
terr_sky_view(weather_station, ...)Details
The sky view factor (\(SVF\)) is calculated as: $$SVF = \frac{1 + \cos(\theta)}{2}$$ for non-valley locations, and $$SVF = \cos(\theta)$$ for valley locations, where \(\theta\) is the slope angle.
The terrain view factor can be calculated by 1 - terr_sky_view(), which represents how much terrain can be seen from the point.