Calculates the roughness length of a surface based on the obstacle height or the type of the surface.
Usage
turb_roughness_length(...)
# Default S3 method
turb_roughness_length(surface_type = NULL, obs_height = NULL, ...)
# S3 method for class 'weather_station'
turb_roughness_length(weather_station, ...)Details
Possible surface types are: "field", "acre", "lawn", "street", "agriculture", "settlement", "coniferous forest", "deciduous forest", "mixed forest", "city", "water", "shrub".
You need to specify only one of surface_type or obs_height.
This function calculates the roughness length (\(z_0\)) of a surface. The roughness length is a measure of the roughness of the surface, which affects the wind profile near the ground. It can be calculated either based on the height of obstacles on the surface or by specifying the type of surface.
When the obstacle height (obs_height) is provided, the roughness length is calculated as 10% of the obstacle height.
When the surface type (surface_type) is provided, the roughness length is looked up from predefined values.
The surface-class lookup values are package parameters. Bendix (2004) is
cited as roughness-length method background.